From stern@rowland.harvard.edu Thu Jul  7 11:12:21 2005
Date: Thu, 7 Jul 2005 14:10:22 -0400 (EDT)
From: Alan Stern <stern@rowland.harvard.edu>
To: Greg KH <greg@kroah.com>
Subject: USB: Usbcore: Don't try to delete unregistered interfaces
Message-ID: <Pine.LNX.4.44L0.0507071402550.6401-100000@iolanthe.rowland.org>

Greg:

This patch handles a rarely-encountered failure mode in usbcore.  It's 
legal for device_add to fail (although now it happens even more rarely 
than before since failure to bind a driver is no longer fatal).  So when 
we destroy the interfaces in a configuration, we shouldn't try to delete 
ones which weren't successfully registered.  Also, failure to register an 
interface shouldn't be fatal either -- I think; you may disagree about 
this part of the patch.

Signed-off-by: Alan Stern <stern@rowland.harvard.edu>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/usb/core/message.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)

--- gregkh-2.6.orig/drivers/usb/core/message.c	2005-07-27 15:16:11.000000000 -0700
+++ gregkh-2.6/drivers/usb/core/message.c	2005-07-27 15:20:37.000000000 -0700
@@ -985,8 +985,10 @@
 		for (i = 0; i < dev->actconfig->desc.bNumInterfaces; i++) {
 			struct usb_interface	*interface;
 
-			/* remove this interface */
+			/* remove this interface if it has been registered */
 			interface = dev->actconfig->interface[i];
+			if (!klist_node_attached(&interface->dev.knode_bus))
+				continue;
 			dev_dbg (&dev->dev, "unregistering interface %s\n",
 				interface->dev.bus_id);
 			usb_remove_sysfs_intf_files(interface);
@@ -1439,7 +1441,7 @@
 		}
 	}
 
-	return ret;
+	return 0;
 }
 
 // synchronous request completion model
